.textview_theme {
    background-color: #EDD2A4;
    background: #EDD2A4;
    color: black;
    font-weight: normal;
    font-size: 12pt;
    font-family: Verdana;
}

.result_theme {
    background-color: #BAE9FF;
    background: #BAE9FF;
    color: black;
    font-weight: normal;
    font-size: 12pt;
    font-family: Verdana;
}

.font_theme {
    font-weight: normal;
    font-size: 12pt;
    font-family: Verdana;
}

.textview_theme:selected {
    color: white;
    background-color: orange;
    }
