from setuptools import setup
setup(name = "helpman", 
version = "2.4", 
description = "quick & easy access to 4000+ manuals / guides / tutorials", 
author = "Nathan SR", 
author_email = "cquickcal@gmail.com",
url = "https://git.fosscommunity.in/SRNathan/Helpman", 
license='GPLv3', 
scripts=['helpman'], 
data_files = [ ("lib/helpman", ["helpman.glade"]),
("lib/helpman", ["helpman.css"]), 
("share/pixmaps", ["helpman.png"]),
("share/pixmaps", ["helpman_small.png"]),
("share/pixmaps", ["info_24x24.png"]),
("share/man/man1", ["helpman.1.gz"]),
("share/metainfo", ["org.gnome.helpman.appdata.xml"]),
("share/applications", ["org.gnome.helpman.desktop"]) ] ) 
